.. _swh-loader-bzr:

.. include:: README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   how-bzr-works

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
